@@ -7,11 +7,21 @@ project_path = file_path[0:end]
 sys.path.append(project_path)
 
 import requests
+
+import mns_common.utils.data_frame_util as data_frame_util
 import json
-import pandas as pd
-from concurrent.futures import ThreadPoolExecutor
 import datetime
+
+import threading
+from concurrent.futures import ThreadPoolExecutor
+import mns_common.component.proxies.proxy_common_api as proxy_common_api
 from loguru import logger
+import concurrent.futures
+import pandas as pd
+import time
+from concurrent.futures import ThreadPoolExecutor, as_completed
+from threading import Lock
+import mns_common.api.em.real_time.real_time_quotes_repeat_api as real_time_quotes_repeat_api
 
 #
 # fields_02 = "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13,f14,f15,f16,f17,f18,f19,f20,f21,f22,f23,f24,f25,f26,f27,f28,f29,f30,f31,f32,f33,f34,f35,f36,f37,f38,f39,f40,f41,f42,f43,f44,f45,f46,f47,f48,f49,f50,f51,f52,f53,f54,f55,f56,f57,f58,f59,f60,f61,f62,f63,f64,f65,f66,f67,f68,f69,f70,f71,f72,f73,f74,f75,f76,f77,f78,f79,f80,f81,f82,f83,f84,f85,f86,f87,f88,f89,f90,f91,f92,f93,f94,f95,f96,f97,f98,f99,f100,f101,f102,f103,f104,f105,f106,f107,f108" \
@@ -20,6 +30,8 @@ from loguru import logger
 #             ",f309,f310,f312,f313,f314,f315,f316,f317,f318,f319,f320,f321,f322,f323,f324,f325,f326,f327,f328,f329,f330,f331,f332,f333,f334,f335,f336,f337,f338,f339,f340,f341,f342,f343,f344,f345,f346,f347,f348,f349,f350,f351,f352,f353,f354,f355,f356,f357,f358,f359,f360,f361,f362,f363,f364,f365,f366,f367,f368,f369,f370,f371,f372,f373,f374,f375,f376,f377,f378,f379,f380,f381,f382,f383,f384,f385,f386,f387,f388,f389,f390,f391,f392,f393,f394,f395,f396,f397,f398,f399,f401"
 
 
+fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"
+
 fields = ("f2,f3,f5,f6,f8,"
           "f9,f10,f22,f12,f13,"
           "f14,f15,f16,f17,f18,"
@@ -39,7 +51,7 @@ min_number = 5600
 page_number = 100
 
 
-def get_stock_page_data(pn, fields, fs, proxies):
+def get_stock_page_data(pn, proxies, page_number, time_out):
     """
     获取单页股票数据
     """
@@ -53,7 +65,7 @@ def get_stock_page_data(pn, fields, fs, proxies):
     params = {
         "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
         "pn": str(pn),
-        "pz": "10000",  # 每页最大200条
+        "pz": str(page_number),  # 每页最大200条
         "po": "1",
         "np": "3",
         "ut": "bd1d9ddb04089700cf9c27f6f7426281",
@@ -67,9 +79,9 @@ def get_stock_page_data(pn, fields, fs, proxies):
     }
     try:
         if proxies is None:
-            r = requests.get(url, params)
+            r = requests.get(url, params, timeout=time_out)
         else:
-            r = requests.get(url, params, proxies=proxies)
+            r = requests.get(url, params, proxies=proxies, timeout=time_out)
         data_text = r.text
         begin_index = data_text.index('[')
         end_index = data_text.index(']')
@@ -113,7 +125,6 @@ def all_stock_ticker_data_new(fields, fs, proxies) -> pd.DataFrame:
 
 
 def get_all_real_time_quotes(proxies):
-    fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"
     # 获取第一页数据
     page_one_df = get_stock_page_data(1, fields, fs, proxies)
     # 数据接口正常返回5600以上的数量
@@ -286,6 +297,91 @@ def rename_real_time_quotes_df(temp_df):
     return temp_df
 
 
+def repeated_acquisition_ask_async(time_out, max_number, num_threads, pages_per_thread):
+    per_page = page_number
+    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
+    result_df = pd.DataFrame()
+
+    # 创建线程锁以确保线程安全
+    df_lock = Lock()
+
+    # 计算每个线程处理的页数范围
+    def process_page_range(start_page, end_page, thread_id):
+        nonlocal result_df
+        local_df = pd.DataFrame()
+        current_page = start_page
+        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
+
+        while current_page <= end_page and current_page <= total_pages:
+            proxies = {"https": proxy_ip, "http": proxy_ip}
+            try:
+                page_df = get_stock_page_data(current_page, proxies, page_number, time_out)
+                if data_frame_util.is_not_empty(page_df):
+                    local_df = pd.concat([local_df, page_df])
+                    logger.info("线程{}获取页面数据成功: {}", thread_id, current_page)
+                    current_page += 1
+                else:
+                    time.sleep(0.2)
+                    proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
+                    logger.info("线程{}获取页面数据失败: {}", thread_id, current_page)
+            except BaseException as e:
+                time.sleep(1)
+                proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
+                logger.error("线程{}处理页面{}时发生错误: {}", thread_id, current_page, e)
+
+        with df_lock:
+            result_df = pd.concat([result_df, local_df])
+        return len(local_df)
+
+    # 计算每个线程的页面范围
+    page_ranges = []
+    for i in range(num_threads):
+        start_page = i * pages_per_thread + 1
+        end_page = (i + 1) * pages_per_thread
+        if start_page > total_pages:
+            break
+        page_ranges.append((start_page, end_page, i + 1))
+
+    # 使用线程池执行任务
+    with concurrent.futures.ThreadPoolExecutor(max_workers=num_threads) as executor:
+        # 提交所有任务
+        futures = [
+            executor.submit(process_page_range, start, end, tid)
+            for start, end, tid in page_ranges
+        ]
+
+        # 等待所有任务完成并获取结果
+        results = []
+        for future in concurrent.futures.as_completed(futures):
+            try:
+                result = future.result()
+                results.append(result)
+            except Exception as e:
+                logger.error("线程执行出错: {}", e)
+
+    return rename_real_time_quotes_df(result_df)
+
+
+def get_stock_real_time_quotes(time_out, pages_per_thread):
+    try_numer = 3
+    while try_numer > 0:
+        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
+        proxies = {"https": proxy_ip,
+                   "http": proxy_ip}
+
+        total_number = real_time_quotes_repeat_api.get_stocks_num(1, proxies, 20, time_out)
+        if total_number > 0:
+            break
+        try_numer = try_numer - 1
+    if total_number == 0:
+        return pd.DataFrame()
+
+    total_pages = (max_number + page_number - 1) // page_number  # 向上取整
+
+    num_threads = int((total_pages / pages_per_thread) + 1)
+    return repeated_acquisition_ask_async(time_out, max_number, num_threads, pages_per_thread)
+
+
 # 示例调用
 if __name__ == "__main__":
     number = 1
