@@ -18,10 +18,59 @@ fields = ("f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,"
           "f18,f20,f21,f26,f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212"),
 fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"
 
+
+max_number = 5800
 # 分页条数
 PAGE_SIZE = 100
 
 
+def get_stocks_num(pn, proxies, page_size, time_out):
+    """
+     获取单页股票数据
+     """
+    # 获取当前日期和时间
+    current_time = datetime.datetime.now()
+
+    # 将当前时间转换为时间戳（以毫秒为单位）
+    current_timestamp_ms = int(current_time.timestamp() * 1000)
+
+    url = "https://33.push2.eastmoney.com/api/qt/clist/get"
+    params = {
+        "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
+        "pn": str(pn),
+        "pz": str(page_size),  # 每页最大200条
+        "po": "0",
+        "np": "3",
+        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
+        "fltt": "2",
+        "invt": "2",
+        "wbp2u": "|0|0|0|web",
+        "fid": "f12",
+        "fs": fs,
+        "fields": fields,
+        "_": current_timestamp_ms
+    }
+    try:
+        if proxies is None:
+            r = requests.get(url, params, timeout=time_out)
+        else:
+            r = requests.get(url, params, proxies=proxies, timeout=time_out)
+
+        data_text = r.text
+
+        begin_index_total = data_text.index('"total":')
+
+        end_index_total = data_text.index('"diff"')
+
+        total_number = int(data_text[begin_index_total + 8:end_index_total - 1])
+
+        return total_number
+
+    except Exception as e:
+        logger.error("获取第{}页股票列表异常:{}", pn, str(e))
+        return 0
+
+
 def get_stock_page_data_time_out(pn, proxies, page_size, time_out):
     """
     获取单页股票数据
@@ -348,6 +397,26 @@ def rename_real_time_quotes_df(temp_df):
         return temp_df
 
 
+def get_stock_real_time_quotes(time_out, pages_per_thread):
+    try_numer = 3
+    while try_numer > 0:
+        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
+        proxies = {"https": proxy_ip,
+                   "http": proxy_ip}
+
+        total_number = get_stocks_num(1, proxies, 20, time_out)
+        if total_number > 0:
+            break
+        try_numer = try_numer - 1
+    if total_number == 0:
+        return pd.DataFrame()
+
+    total_pages = (max_number + PAGE_SIZE - 1) // PAGE_SIZE  # 向上取整
+
+    num_threads = int((total_pages / pages_per_thread) + 1)
+    return repeated_acquisition_ask_async(time_out, max_number, num_threads, pages_per_thread)
+
+
 if __name__ == '__main__':
 
     while True:
@@ -355,5 +424,5 @@ if __name__ == '__main__':
         # proxies = {"https": proxy_ip,
         #            "http": proxy_ip}
         time_out = 10  # Set the timeout value
-        result = repeated_acquisition_ask_async(time_out, 5800, 6, 10)
+        result = get_stock_real_time_quotes(time_out, 10)
         print(result)
