@@ -115,7 +115,7 @@ def get_concept_detail_by_wen_cai(concept_name):
 
 
 if __name__ == '__main__':
-    zt_df = wen_cai_api('涨停', 'stock', )
+    zt_df = wen_cai_api('001203涨停分析', 'stock', )
     print(zt_df)
     # concept_detail_df = get_concept_detail_by_wen_cai("光纤概念")
     # concept_df = get_concept_index_by_wen_cai()
