@@ -203,3 +203,8 @@ def symbol_add_prefix(symbol):
         return '0.' + symbol_simple
     else:
         return '0.' + symbol_simple
+
+
+# 排除改变代码的北交所
+def exclude_change_bjs_code(df):
+    return df[~df['symbol'].str.startswith(('8', '4'))]
